library(tidyverse)
library(haven)

# Choix du conjoint, 1959
cc59 <- read_sas("../../Girard - 1959 - Le choix du conjoint (IE0086 - 081)/Fichiers/SAS V8 PC/IE0186_SASV8win.sas7bdat")

cc59$Q5COMM2 <- cc59$Q5COMM
cc59$Q6COMM2 <- cc59$Q6COMM
cc59$Q5COMM2[cc59$QUEST5 == "0"] <- "NRP"
cc59$Q6COMM2[cc59$QUEST6 == "0"] <- "NRP"

with(subset(cc59, QUEST5 %in% 0:5 & !ENQUETE %in% c(0, 6, 8)),
     prop.table(table(Q5COMM2, QUEST5 %in% 1:2, useNA="a")))

cc59 <- mutate(cc59, enquete="cc",
               sexe=case_when(ENQUETE %in% c(0, 6, 8) ~ "H", ENQUETE %in% c(5, 7, 9) ~ "F"),
               premh=NA, premf=NA,
               anaissh=1959-MAGE, anaissf=1959-FAGE,
               adeb=1900+ANMAR,
               ageh=adeb-anaissh, agef=adeb-anaissf,
               marie="Oui",
               diph=recode_factor(MDIPLOME, `0`="Aucun", `1`="CEP", `2`="CAP/BEP", `3`="BEPS/BEPC",
                                  `4`="Bac", `5`="Supérieur", `9`="Aucun"),
               dipf=recode_factor(FDIPLOME, `0`="Aucun", `1`="CEP", `2`="CAP/BEP", `3`="BEPS/BEPC",
                                  `4`="Bac", `5`="Supérieur", `9`="Aucun"),
               dip2h=diph, dip2f=dipf,
               # 91: Italiens (MNATPERE 2), 92: Polonais (3), 93: Belges (4), 94: Espagnols (5), 95: Autres étrangers (6)
               # 96, 97, 98 : signification inconnue
               paysh=case_when(HDPNAIS <= 90 ~ "France", HDPNAIS %in% c(91, 93, 94) ~ "Europe de l'Ouest",
                               HDPNAIS == 92 ~ "Europe de l'Est", HDPNAIS == 95 ~ "Autres"),
               paysf=case_when(FDPNAIS <= 90 ~ "France", FDPNAIS %in% c(91, 93, 94) ~ "Europe de l'Ouest",
                               FDPNAIS == 92 ~ "Europe de l'Est", FDPNAIS == 95 ~ "Autres"),
               paysph=recode_factor(MNATPERE, `1`="France", `2`="Europe de l'Ouest", `4`="Europe de l'Ouest", `5`="Europe de l'Ouest",
                                    `3`="Europe de l'Est", `6`="Autre", .default=NA_character_),
               paysmh=recode_factor(MNATMERE, `1`="France", `2`="Europe de l'Ouest", `4`="Europe de l'Ouest", `5`="Europe de l'Ouest",
                                    `3`="Europe de l'Est", `6`="Autre", `0`="France", .default=NA_character_),
               payspf=recode_factor(FNATPERE, `1`="France", `2`="Europe de l'Ouest", `4`="Europe de l'Ouest", `5`="Europe de l'Ouest",
                                    `3`="Europe de l'Est", `6`="Autre", .default=NA_character_),
               paysmf=recode_factor(FNATMERE, `1`="France", `2`="Europe de l'Ouest", `4`="Europe de l'Ouest", `5`="Europe de l'Ouest",
                                    `3`="Europe de l'Est", `6`="Autre", `0`="France", .default=NA_character_),
               depnaissh=if_else(paysh == "France", as.character(na_if(HDPNAIS, 99)), as.character(paysh)),
               depnaissf=if_else(paysf == "France", as.character(na_if(FDPNAIS, 99)), as.character(paysf)),
               # On prend la CS à l'enquête pour les inactifs lors de la mise en couple
               csh=factor(if_else(HCSPAVT %in% 11:69, substr(HCSPAVT, 1, 1), substr(HCSPACT, 1, 1))),
               csph=factor(if_else(HCSPP %in% 11:85, substr(HCSPP, 1, 1), NA_character_)),
               cspf=factor(if_else(FCSPP %in% 11:85, substr(FCSPP, 1, 1), NA_character_)),
               # À quelle année correspond la population ?
               turnaissh=recode_factor(MSTRCOM, `1`="<2000", `2`="2000-100000", `3`="2000-100000", `4`="2000-100000",
                                       `5`=">100000", `6`=">100000", .default=NA_character_),
               turnaissf=recode_factor(FSTRCOM, `1`="<2000", `2`="2000-100000", `3`="2000-100000", `4`="2000-100000",
                                       `5`=">100000", `6`=">100000", .default=NA_character_),
               turrench=recode_factor(MSTRMAR, `1`="<2000", `2`="2000-100000", `3`="2000-100000", `4`="2000-100000",
                                      `5`=">100000", `6`=">100000", .default=NA_character_),
               turrencf=recode_factor(FSTRMAR, `1`="<2000", `2`="2000-100000", `3`="2000-100000", `4`="2000-100000",
                                      `5`=">100000", `6`=">100000", .default=NA_character_),
               religh=recode(MRELIG, `0`="Sans religion", `1`="Catholique", `2`="Catholique", `3`="Catholique",
                             `4`="Protestant", `5`="Protestant", `6`="Protestant",
                             `7`="Juif", `8`="Juif", `9`="Juif"),
               religf=recode(FRELIG, `0`="Sans religion", `1`="Catholique", `2`="Catholique", `3`="Catholique",
                             `4`="Protestant", `5`="Protestant", `6`="Protestant",
                             `7`="Juif", `8`="Juif", `9`="Juif"),
               homorelig=if_else(religh==religf, "Homogame", "Hétérogame"),
               avisfam=recode_factor(QUEST5, `1`="Très favorable", `2`="Favorable",
                                     `3`="Défavorable", `4`="Très défavorable", `7`="Défavorable",
                                     .default=NA_character_),
               avisfam2=recode_factor(QUEST5, `1`="Favorable", `2`="Favorable", `5`="Favorable",
                                      `3`="Défavorable", `4`="Défavorable", `7`="Défavorable",
                                      .default=NA_character_),
               avisfam3=recode(QUEST5, `1`=4, `2`=3, `0`=2.5, `5`=2.5, `3`=2, `4`=1, `7`=2,
                               .default=NA_real_),
               avisbfam=recode_factor(QUEST6, `1`="Très favorable", `2`="Favorable",
                                      `3`="Défavorable", `4`="Très défavorable", `7`="Défavorable",
                                      .default=NA_character_),
               avisbfam2=recode_factor(QUEST6, `1`="Favorable", `2`="Favorable", `5`="Favorable",
                                       `3`="Défavorable", `4`="Défavorable", `7`="Défavorable",
                                       .default=NA_character_),
               avisbfam3=recode(QUEST6, `1`=4, `2`=3, `0`=2.5, `5`=2.5, `3`=2, `4`=1, `7`=2,
                                .default=NA_real_),
               # Problème dans les modalités : 5 « Avant le mariage sans autre précision »
               # inclut probablement à la fois des cas où les familles se connaissaient déjà
               # et des présentations avant le mariage sans autre précision
               # (surestimation, notamment pour les urbains et les conjoints de départements différents)
               confam=if_else(RENCFAM == 5, "Se connaissaient", "Ne se connaissaient pas"),
               conbfam=NA,
               cadrefam=if_else(is.na(CADRE), NA_character_,
                                if_else(CADRE %in% c(0, 7:9), "Cadre familial", "Autre cadre")),
               attiphy=if_else(OPIN5 == "0", NA_character_,
                               if_else(OPIN5 %in% c("1", "3"), "Important", "Jamais important")))

# Formation des couples, 1983-84
fc <- read_sas("../../Bozon Héran - 1983 - La formation des couples (IE0164)/Fichiers_de_données/SAS/IE0164_F.sas7bdat")


fc <- mutate(fc, enquete="fc",
             sexe=recode_factor(SEXE, `1`="H", `2`="F"),
             # On ne peut inférer le rang de l'union qu'à partir du fait d'avoir déjà été marié
             prem=(MAT == "1" & TOUJOUR != "2") | MAT == "4",
             premcjt=MATCJT == "4",
             premh=if_else(sexe == "H", prem, premcjt),
             premf=if_else(sexe == "F", prem, premcjt),
             adeb=if_else(DATS %in% 54:84, 1900+DATS, NA_real_),
             anaissh=(1984-HAGE), anaissf=(1984-FAGE),
             ageh=adeb-anaissh, agef=adeb-anaissf,
             marie=if_else(DATMMOI == "0", "Non", "Oui"),
             HDIPLOS2=if_else(HDIPLOG %in% 4:5, 8, HDIPLOS),
             FDIPLOS2=if_else(FDIPLOG %in% 4:5, 8, FDIPLOS),
             diph=recode_factor(HDIPLOS2, `1`="Aucun", `2`="CEP", `3`="CAP/BEP", `4`="BEPS/BEPC",
                                `5`="Bac", `6`="Bac", `7`="Bac+2 pro.", `8`="DEUG et ≥Bac+3"),
             dipf=recode_factor(FDIPLOS2, `1`="Aucun", `2`="CEP", `3`="CAP/BEP", `4`="BEPS/BEPC",
                                `5`="Bac", `6`="Bac", `7`="Bac+2 pro.", `8`="DEUG et ≥Bac+3"),
             dip2h=recode_factor(HDIPLOS2, `1`="Aucun", `2`="CEP", `3`="CAP/BEP", `4`="BEPS/BEPC",
                                 `5`="Bac", `6`="Bac", `7`="Bac+2 pro.", `8`="DEUG et ≥Bac+3"),
             dip2f=recode_factor(FDIPLOS2, `1`="Aucun", `2`="CEP", `3`="CAP/BEP", `4`="BEPS/BEPC",
                                 `5`="Bac", `6`="Bac", `7`="Bac+2 pro.", `8`="DEUG et ≥Bac+3"),
             # On suppose que les Français de naissance sont nés en France et les autres à l'étranger
             # puisque cette information n'est pas disponible et que les codes département et pays sont mélangés
             # Les codes de pays vont de 101 à 118 (voir DEPPERE et DEPMERE)
             paysh=case_when(HFRANC != 1 & DEPNH %in% c(4:6, 10:14) ~ "Europe de l'Ouest",
                             HFRANC != 1 & DEPNH %in% c(7, 8, 15) ~ "Europe de l'Est",
                             HFRANC != 1 & DEPNH %in% 1:3 ~ "Afrique du Nord",
                             HFRANC != 1 & DEPNH == 16 ~ "Afrique sub-saharienne",
                             HFRANC != 1 & DEPNH %in% 17:18 ~ "Autres",
                             DEPNH <= 98 ~ "France",
                             DEPNH == 99 ~ NA_character_),
             paysf=case_when(FFRANC != 1 & DEPNF %in% c(4:6, 10:14) ~ "Europe de l'Ouest",
                             FFRANC != 1 & DEPNF %in% c(7, 8, 15) ~ "Europe de l'Est",
                             FFRANC != 1 & DEPNF %in% 1:3 ~ "Afrique du Nord",
                             FFRANC != 1 & DEPNF == 16 ~ "Afrique sub-saharienne",
                             FFRANC != 1 & DEPNF %in% 17:18 ~ "Autres",
                             DEPNF <= 98 ~ "France",
                             DEPNF == 99 ~ NA_character_),
             depnaissh=if_else(paysh == "France", as.character(na_if(DEPNH, 99)), paysh),
             depnaissf=if_else(paysf == "France", as.character(na_if(DEPNF, 99)), paysf),
             # Reconstituer la Seine et Oise (78) et la Seine (75)
             depnaissh=recode(depnaissh, "91"="78", "95"="78", "92"="75", "93"="75", "94"="75"),
             depnaissf=recode(depnaissf, "91"="78", "95"="78", "92"="75", "93"="75", "94"="75"),
             DIALH=if_else(sexe == "H", DIAL1, DIAL2),
             DIALF=if_else(sexe == "F", DIAL1, DIAL2),
             paysph=case_when(DIALH %in% c(4:6, 10:14) ~ "Europe de l'Ouest",
                              DIALH %in% c(3, 7, 8, 15) ~ "Europe de l'Est",
                              DIALH %in% 1:2 ~ "Afrique du Nord", DIALH == 16 ~ "Afrique sub-saharienne",
                              DIALH %in% 17:18 ~ "Autre", TRUE ~ "France"),
             payspf=case_when(DIALF %in% c(4:6, 10:14) ~ "Europe de l'Ouest",
                              DIALF %in% c(3, 7, 8, 15) ~ "Europe de l'Est",
                              DIALF %in% 1:2 ~ "Afrique du Nord", DIALF == 16 ~ "Afrique sub-saharienne",
                              DIALF %in% 17:18 ~ "Autre", TRUE ~ "France"),
             paysmh=paysph, paysmf=payspf,
             csph=if_else(CSPPH %in% 10:69, substr(CSPPH, 1, 1), NA_character_),
             cspf=if_else(CSPPF %in% 10:69, substr(CSPPF, 1, 1), NA_character_),
             turnaissh=case_when(TU75NH %in% 1:6 ~ "<2000", TU75NH %in% 7:52 ~ "2000-100000",
                                 TU75NH %in% 61:81 ~ ">100000"),
             turnaissf=case_when(TU75NF %in% 1:6 ~ "<2000", TU75NF %in% 7:52 ~ "2000-100000",
                                 TU75NF %in% 61:81 ~ ">100000"),
             turrench=case_when(TU75RH %in% 1:6 ~ "<2000", TU75RH %in% 7:52 ~ "2000-100000",
                                TU75RH %in% 61:81 ~ ">100000"),
             turrencf=case_when(TU75RF %in% 1:6 ~ "<2000", TU75RF %in% 7:52 ~ "2000-100000",
                                TU75RF %in% 61:81 ~ ">100000"),
             homorelig=recode_factor(ELVRELIG, `1`="Homogame", `3`="Homogame", `2`="Hétérogame", `9`=NA_character_),
             avisfam=NA, avisbfam=NA,
             avisfam2=case_when(ATITUP1 %in% c(0, 6) ~ if_else(ATITUM1 %in% 4:5, "Défavorable", "Favorable"),
                                ATITUM1 %in% c(0, 6) ~ if_else(ATITUP1 %in% 4:5, "Défavorable", "Favorable"),
                                ATITUP1 %in% 4:5 | ATITUM1 %in% 4:5 ~ "Défavorable",
                                TRUE ~ "Favorable"),
             avisbfam2=case_when(ATITUP2 %in% c(0, 6) ~ if_else(ATITUM2 %in% 4:5, "Défavorable", "Favorable"),
                                 ATITUM2 %in% c(0, 6) ~ if_else(ATITUP2 %in% 4:5, "Défavorable", "Favorable"),
                                 ATITUP2 %in% 4:5 | ATITUM2 %in% 4:5 ~ "Défavorable",
                                 TRUE ~ "Favorable"),
             confam=if_else(PAREPOC == 1, "Se connaissaient", "Ne se connaissaient pas"),
             conbfam=if_else(PARFORM == 1, "Connaissait ses beaux-parents", "Ne les connaissait pas"),
             cadrefam=if_else(CADRPRIM %in% c(920, 960, 970, 980), NA_character_,
                              if_else(CADRPRIM %in% c(160, 165, 170, 175, 190, # Mariages sauf amis
                                                      500, 507, 510, # La rue, le trottoir, la cité, le quartier, village
                                                      830, 836, 837, 841, 850, 857, # Chez ou par un parent
                                                      860, 865, 870, 876, 877, 880, 890, 897), # Toujours connus, voisinage
                                      "Cadre familial", "Autre cadre")),
             attiphy=if_else(ATIRPHYS == "9", NA_character_,
                             if_else(ATIRPHYS %in% 1:2, "Important", "Jamais important")))

# EPIC, 2013-2014
epic <- read_sas("../../Données EPIC 25-01/repondant.sas7bdat")
epic <- subset(epic, IndCOU == 1 & M_COUCOHA == 1) # Garder uniquement les couples cohabitants

epic <- mutate(epic, enquete="epic",
               sexe=recode_factor(SEXER, `1`="H", `2`="F"),
               premh=if_else(sexe == "H", H_NREL_C == "1", na_if(H_COUC_C, "9") == "2"),
               premf=if_else(sexe == "F", H_NREL_C == "1", na_if(H_COUC_C, "9") == "2"),
               adeb=na_if(C_ADEB, 9999),
               marie=recode_factor(na_if(C_MAR, ""), `1`="Oui", `2`="Non"),
               anaissh=if_else(sexe == "H", ANAISR, na_if(H_ANAISC_C, 9999)),
               anaissf=if_else(sexe == "F", ANAISR, na_if(H_ANAISC_C, 9999)),
               ageh=adeb-anaissh, agef=adeb-anaissf,
               C_DIPLOMEH=if_else(sexe == "H", M_DIPLOME, C_DIPLOMEC),
               C_DIPLOMEF=if_else(sexe == "F", M_DIPLOME, C_DIPLOMEC),
               diph=recode_factor(C_DIPLOMEH, `1`="Aucun", `2`="CEP", `3`="BEPS/BEPC", `4`="CAP/BEP", 
                                  `5`="Bac", `6`="Bac+2", `7`="Bac+3/Bac+4", `8`="≥Bac+5", `9`="≥Bac+5",
                                  .default=NA_character_),
               dipf=recode_factor(C_DIPLOMEF, `1`="Aucun", `2`="CEP", `3`="BEPS/BEPC", `4`="CAP/BEP", 
                                  `5`="Bac", `6`="Bac+2", `7`="Bac+3/Bac+4", `8`="≥Bac+5", `9`="≥Bac+5",
                                  .default=NA_character_),
               dip2h=recode_factor(C_DIPLOMEH, `1`="Aucun", `2`="CEP", `3`="BEPS/BEPC", `4`="CAP/BEP",
                                   `5`="Bac", `6`="Bac+2", `7`="≥Bac+3", `8`="≥Bac+3", `9`="≥Bac+3",
                                   .default=NA_character_),
               dip2f=recode_factor(C_DIPLOMEF, `1`="Aucun", `2`="CEP", `3`="BEPS/BEPC", `4`="CAP/BEP",
                                   `5`="Bac", `6`="Bac+2", `7`="≥Bac+3", `8`="≥Bac+3", `9`="≥Bac+3",
                                   .default=NA_character_),
               PAYSNAISH=if_else(sexe == "H", M_PAYSNAISR, na_if(C_PAYSNAISR, "")),
               PAYSNAISF=if_else(sexe == "F", M_PAYSNAISR, na_if(C_PAYSNAISR, "")),
               # Europe de l'Ouest correspond à l'ensemble de l'Europe, Afrique du Nord au Maghreb
               # et Afrique sub-saharienne au reste de l'Afrique
               paysh=recode_factor(PAYSNAISH, `1`="France", `2`="Europe de l'Ouest", `3`="Europe de l'Ouest",
                                   `4`="Afrique du Nord",`5`="Afrique sub-saharienne",
                                   `6`="Autres", .default=NA_character_),
               paysf=recode_factor(PAYSNAISF, `1`="France", `2`="Europe de l'Ouest", `3`="Europe de l'Ouest",
                                   `4`="Afrique du Nord", `5`="Afrique sub-saharienne",
                                   `6`="Autres", .default=NA_character_),
               paysph=paysh, paysmh=paysh, payspf=paysf, paysmf=paysf,
               DEPNAISH=if_else(sexe == "H", M_DEPNAIS, na_if(C_DEPNAIS, "99")),
               DEPNAISF=if_else(sexe == "F", M_DEPNAIS, na_if(C_DEPNAIS, "99")),
               depnaissh=if_else(PAYSNAISH == 1, as.character(na_if(DEPNAISH, "")), as.character(paysh)),
               depnaissf=if_else(PAYSNAISF == 1, as.character(na_if(DEPNAISF, "")), as.character(paysf)),
               depnaissh=case_when(depnaissh %in% c("9A", "9B", "9C", "9D") ~ "DOM",
                                   depnaissh %in% c("9F", "9H", "9I") ~ "TOM",
                                   TRUE ~ depnaissh),
               depnaissf=case_when(depnaissf %in% c("9A", "9B", "9C", "9D") ~ "DOM",
                                   depnaissf %in% c("9F", "9H", "9I") ~ "TOM",
                                   TRUE ~ depnaissf),
               # Reconstituer la Seine et Oise (78) et la Seine (75)
               depnaissh=recode(depnaissh, "91"="78", "95"="78", "92"="75", "93"="75", "94"="75"),
               depnaissf=recode(depnaissf, "91"="78", "95"="78", "92"="75", "93"="75", "94"="75"),
               CS8PH=coalesce(na_if(if_else(sexe == "H", F_CS8P, C_CS8PC), ""),
                              na_if(if_else(sexe == "H", F_CS8M, C_CS8MC), "")),
               CS8PF=coalesce(na_if(if_else(sexe == "F", F_CS8P, C_CS8PC), ""),
                              na_if(if_else(sexe == "F", F_CS8M, C_CS8MC), "")),
               csph=na_if(CS8PH, 99), cspf=na_if(CS8PF, 99),
               turnaissh=NA, turnaissf=NA, turrench=NA, turrencf=NA,
               homorelig=recode_factor(H_RESREL_C, `1`="Homogame", `2`="Homogame", `3`="Hétérogame", `4`="Hétérogame",
                                       .default=NA_character_),
               avisfam=NA, avisbfam=NA,
               avisfam2=recode_factor(C_AVISFAM, `1`="Favorable", `2`="Défavorable", `3`="Défavorable",
                                      .default=NA_character_),
               avisbfam2=recode_factor(C_AVISFAMC, `1`="Favorable", `2`="Défavorable", `3`="Défavorable",
                                       .default=NA_character_),
               confam=NA,
               conbfam=if_else(C_DURJRENC == 99995, "Connaissait ses beaux-parents", "Ne les connaissait pas"),
               cadrefam=if_else(H_LIEU1_C %in% 97:99, NA_character_,
                                if_else(H_LIEU1_C %in% c("09", "12"), "Cadre familial", "Autre cadre")),
               attiphy=if_else(R_ATTIPHY == "9", NA_character_,
                               if_else(R_ATTIPHY %in% 1:2, "Important", "Jamais important")))


# Fusion des enquêtes
vars <- c("enquete", "sexe", "premh", "premf", "adeb", "ageh", "anaissh", "anaissf", "agef", "marie",
          "diph", "dipf", "dip2h", "dip2f", "csph", "cspf",
          "depnaissh", "depnaissf", "paysh", "paysf", "paysph", "payspf", "paysmh", "paysmf",
          "turnaissh", "turnaissf", "turrench", "turrencf",
          "homorelig", "avisfam2", "avisbfam2", "confam", "conbfam",
          "cadrefam", "attiphy")
dat <- rbind(cc59[vars], fc[vars], epic[vars])

dat <- mutate(dat,
              enquete=factor(enquete, levels=c("cc", "fc", "epic")),
              adeb10=factor(floor(adeb/10)*10),
              anaiss10h=factor(floor(anaissh/10)*10),
              anaiss10f=factor(floor(anaissf/10)*10),
              agemoy=(ageh+agef)/2,
              ecartage=ageh-agef,
              ecartageq=cut(ecartage, c(-100, -2, 0, 2, 5, 10, 100), right=FALSE),
              homodip=if_else(diph==dipf, "Homogame", "Hétérogame"),
              homodip2=if_else(dip2h==dip2f, "Homogame", "Hétérogame"),
              hyperdip=case_when(diph==dipf ~ "Homogame",
                                 as.numeric(diph) > as.numeric(dipf) ~ "Homme > Femme",
                                 as.numeric(dipf) > as.numeric(diph) ~ "Femme > Homme"),
              hyperdip2=case_when(dip2h==dip2f ~ "Homogame",
                                  as.numeric(dip2h) > as.numeric(dip2f) ~ "Homme > Femme",
                                  as.numeric(dip2f) > as.numeric(dip2h) ~ "Femme > Homme"),
              homocsp=if_else(csph==cspf, "Homogame", "Hétérogame"),
              homodep=if_else(depnaissh==depnaissf, "Homogame", "Hétérogame"),
              paysh.fr=paysh == "France" & paysph == "France" & paysmh == "France",
              paysh.eo=paysh == "Europe de l'Ouest" | paysph == "Europe de l'Ouest" | paysmh == "Europe de l'Ouest",
              paysh.ee=paysh == "Europe de l'Est" | paysph == "Europe de l'Est" | paysmh == "Europe de l'Est",
              paysh.an=paysh == "Afrique du Nord" | paysph == "Afrique du Nord" | paysmh == "Afrique du Nord",
              paysh.as=paysh == "Afrique sub-saharienne" | paysph == "Afrique sub-saharienne" | paysmh == "Afrique sub-saharienne",
              paysh.au=paysh == "Autre" | paysph == "Autre" | paysmh == "Autre",
              paysf.fr=paysf == "France" & payspf == "France" & paysmf == "France",
              paysf.eo=paysf == "Europe de l'Ouest" | payspf == "Europe de l'Ouest" | paysmf == "Europe de l'Ouest",
              paysf.ee=paysf == "Europe de l'Est" | payspf == "Europe de l'Est" | paysmf == "Europe de l'Est",
              paysf.an=paysf == "Afrique du Nord" | payspf == "Afrique du Nord" | paysmf == "Afrique du Nord",
              paysf.as=paysf == "Afrique sub-saharienne" | payspf == "Afrique sub-saharienne" | paysmf == "Afrique sub-saharienne",
              paysf.au=paysf == "Autre" | payspf == "Autre" | paysmf == "Autre",
              homopays=if_else(paysh.fr == paysf.fr &
                               (paysh.eo == paysf.eo | paysh.ee == paysf.ee | paysh.an == paysf.an |
                                paysh.as == paysf.as | paysh.au == paysf.au), "Homogame", "Hétérogame"),
              homopays2=if_else(paysh == paysf, "Homogame", "Hétérogame"),
              homoturnaiss=if_else(turnaissh == turnaissf, "Homogame", "Hétérogame"),
              homo=(homocsp=="Homogame") + (homodip=="Homogame") + (homodep=="Homogame") + 
                   (homorelig=="Homogame") + (homopays=="Homogame") + (abs(ecartage) <= 2))

dat <- group_by(dat, anaissh) %>% mutate(agenormh=scale(ageh, scale=FALSE)) %>% ungroup()
dat <- group_by(dat, anaissf) %>% mutate(agenormf=scale(agef, scale=FALSE)) %>% ungroup()

plotdat <- subset(dat, adeb > 1918 & (enquete != "fc" | adeb > 1956) & (enquete != "epic" | adeb > 1960))
save(plotdat, cc59, fc, epic, file="dat.RData")
